<?php defined('BASEPATH') OR exit('No direct script access allowed'); ?>

ERROR - 2024-02-01 05:48:01 --> $config['composer_autoload'] is set to TRUE but /home/artechsy/public_html/live-education.artech-system.com/application/vendor/autoload.php was not found.
ERROR - 2024-02-01 13:34:22 --> $config['composer_autoload'] is set to TRUE but /home/artechsy/public_html/live-education.artech-system.com/application/vendor/autoload.php was not found.
ERROR - 2024-02-01 13:34:22 --> 404 Page Not Found: Administrator/index.php
